Name:		cryfs
Version:	0.11.4
Release:	%mkrel 5
Summary:	Cryptographic filesystem for the cloud
License:	LGPLv3+
Group:		File tools
URL:		https://www.cryfs.org
Source0:	https://github.com/cryfs/cryfs/releases/download/%{version}/%{name}-%{version}.tar.xz
Patch0:		cryfs-0.10.2-static.patch
Patch1:		cryfs-unbundle-libs.patch

BuildRequires:	cmake
BuildRequires:	cmake(range-v3)
BuildRequires:	cmake(spdlog)
BuildRequires:	gcc-c++
BuildRequires:	gzip
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(cryptopp) >= 8.2

Requires:	fuse

%description
CryFS provides a FUSE-based mount that encrypts file contents, file
sizes, metadata and directory structure. It uses encrypted same-size
blocks to store both the files themselves and the blocks' relations
to one another. These blocks are stored as individual files in the
base directory, which can then be synchronized to remote storage
(using an external tool).

%prep
%setup -c -q
%autopatch -p1

# install files with all build types
sed -i -e '/CONFIGURATIONS/d' $(find . -name "CMakeLists.txt")

%build
export CFLAGS="$RPM_OPT_FLAGS -DFMT_DEPRECATED_OSTREAM"
export CXXFLAGS="$RPM_OPT_FLAGS -DFMT_DEPRECATED_OSTREAM"
%cmake \
  -DDEPENDENCY_CONFIG=cmake-utils/DependenciesFromLocalSystem.cmake \
  -DUSE_SYSTEM_LIBS=ON \
  -DBUILD_TESTING=OFF \
  -DBoost_USE_STATIC_LIBS=OFF \
  -DCRYFS_UPDATE_CHECKS=OFF

%cmake_build

%install
%cmake_install

%files
%doc README.md ChangeLog.txt
%license LICENSE.txt
%{_bindir}/cryfs*
%{_mandir}/man?/cryfs*


%changelog
* Wed Jun 19 2024 wally <wally> 0.11.4-5.mga10
+ Revision: 2075324
- rebuild for boost 1.85.0

* Wed May 08 2024 wally <wally> 0.11.4-4.mga10
+ Revision: 2062875
- rebuild for spdlog 1.14.1

* Sat Feb 10 2024 daviddavid <daviddavid> 0.11.4-3.mga10
+ Revision: 2040063
- rebuild for new spdlog

* Fri Jan 12 2024 wally <wally> 0.11.4-2.mga10
+ Revision: 2030522
- rebuild for boost 1.84.0

* Sun Nov 26 2023 daviddavid <daviddavid> 0.11.4-1.mga10
+ Revision: 2009685
- new version: 0.11.4

* Wed Sep 27 2023 wally <wally> 0.11.3-4.mga10
+ Revision: 1991423
- rebuild for boost 1.83.0

* Thu Sep 07 2023 daviddavid <daviddavid> 0.11.3-3.mga10
+ Revision: 1984963
- rebuild for new spdlog

* Sat Dec 24 2022 wally <wally> 0.11.3-2.mga9
+ Revision: 1926458
- rebuild for boost 1.81.0

* Tue Nov 29 2022 daviddavid <daviddavid> 0.11.3-1.mga9
+ Revision: 1912366
- new version: 0.11.3

* Wed Nov 16 2022 daviddavid <daviddavid> 0.11.2-4.mga9
+ Revision: 1907871
- rebuild for new spdlog

* Thu Oct 13 2022 neoclust <neoclust> 0.11.2-3.mga9
+ Revision: 1896763
- Fix build against new fmt

* Thu Oct 13 2022 papoteur <papoteur> 0.11.2-2.mga9
+ Revision: 1896704
- Rebuild for fmt 9

* Sun Sep 11 2022 neoclust <neoclust> 0.11.2-1.mga9
+ Revision: 1886952
- New version 	0.11.2

* Sun Jul 03 2022 wally <wally> 0.11.0-4.mga9
+ Revision: 1867236
- rebuild for boost 1.79.0

* Wed Mar 30 2022 umeabot <umeabot> 0.11.0-3.mga9
+ Revision: 1833744
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 0.11.0-2.mga9
+ Revision: 1762689
- rebuild for boost 1.78.0

* Sat Sep 11 2021 wally <wally> 0.11.0-1.mga9
+ Revision: 1745144
- new version 0.11.0
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.10.2-4.mga9
+ Revision: 1722946
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 0.10.2-3.mga8
+ Revision: 1666744
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.10.2-2.mga8
+ Revision: 1661986
- rebuild for boost 1.74.0

* Fri Jun 05 2020 daviddavid <daviddavid> 0.10.2-1.mga8
+ Revision: 1590595
- new version: 0.10.2

* Sun May 03 2020 wally <wally> 0.9.11-4.mga8
+ Revision: 1578040
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.9.11-3.mga8
+ Revision: 1544598
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.9.11-2.mga8
+ Revision: 1483353
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Nov 27 2019 daviddavid <daviddavid> 0.9.11-1.mga8
+ Revision: 1463058
- new version: 0.9.11

* Tue Nov 26 2019 daviddavid <daviddavid> 0.9.10-2.mga8
+ Revision: 1463032
- rebuild for new libcryptopp 8.2.0

* Sun Feb 10 2019 daviddavid <daviddavid> 0.9.10-1.mga7
+ Revision: 1364961
- new version: 0.9.10

* Tue Oct 16 2018 wally <wally> 0.9.9-2.mga7
+ Revision: 1321021
- rebuild for new boost 1.68.0

* Mon Oct 15 2018 daviddavid <daviddavid> 0.9.9-1.mga7
+ Revision: 1320572
- initial package cryfs

